//
//  ScanViewController.m
//  BTBloodPBLEManager-Demo
//
//  Created by 倍泰 on 13/03/2019.
//  Copyright © 2019 ebelter. All rights reserved.
//

#import "ScanViewController.h"
#import "BTBloodPressureSDK/BTBloodPBLEManager.h"
#import "SVProgressHUD/SVProgressHUD.h"

@interface ScanViewController ()<UITableViewDelegate,UITableViewDataSource,BTBloodPBLEManagerDelegate>
@property (nonatomic,strong) NSMutableArray *datasourceArr;
@property (nonatomic,strong) BTBloodPBLEManager *bleManager;
@end

@implementation ScanViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"scancell"];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    if (self.datasourceArr.count) {
        [self.datasourceArr removeAllObjects];
        [self.tableView reloadData];
    }
    
    self.bleManager = [BTBloodPBLEManager shareBTBloodPBLEManager];
    self.bleManager.delegate = self;
    [self.bleManager setDeviceBleName:@"Belter"];
}

- (IBAction)scanButtonClick:(id)sender {
    // 如果手机蓝牙已开启
    if (self.bleManager.bleState == CBManagerStatePoweredOn) {
        // 开始扫描
        [self.bleManager startScan];
    }
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.datasourceArr.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"scancell" forIndexPath:indexPath];
    
    NSUUID *uuid = self.datasourceArr[indexPath.row];
    cell.textLabel.text = uuid.UUIDString;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    
    NSUUID *uuid = self.datasourceArr[indexPath.row];
    self.bleManager.selectDeviceIdt = uuid;
    
    [self performSegueWithIdentifier:@"showTest" sender:nil];
}

#pragma mark - BTBloodPBLEManagerDelegate
- (void)BTBloodPBLEManagerDidUpdateState:(CBManagerState)state
{
    NSLog(@"[ScanViewController]BTBloodPBLEManagerDidUpdateState: %ld",state);
    if (state == CBManagerStatePoweredOn) {
        [self.bleManager startScan];
    }else{
        [SVProgressHUD showInfoWithStatus:@"Please turn on your iPhone's bluetooth"];
    }
}

- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didDiscoverDeviceName:(NSString *)name macAddress:(NSData *)mac uuid:(NSUUID *)deviceUUID
{
    NSLog(@"[ScanViewController]didDiscoverDevice --- Name:%@, Mac:%@,uuid:%@",name,mac,deviceUUID);
    if (![self.datasourceArr containsObject:deviceUUID]) {
        [self.datasourceArr addObject:deviceUUID];
        [self.tableView reloadData];
    }
}

- (NSMutableArray *)datasourceArr
{
    if (!_datasourceArr) {
        _datasourceArr = [NSMutableArray array];
    }
    return _datasourceArr;
}

@end
