//
//  TestViewController.m
//  BTBloodPBLEManager-Demo
//
//  Created by 倍泰 on 13/03/2019.
//  Copyright © 2019 ebelter. All rights reserved.
//

#import "TestViewController.h"
#import "BTBloodPressureSDK/BTBloodPBLEManager.h"
#import "SVProgressHUD/SVProgressHUD.h"

@interface TestViewController ()<BTBloodPBLEManagerDelegate>

@property (nonatomic,strong) BTBloodPBLEManager *bleManager;

@property (weak, nonatomic) IBOutlet UILabel *activeSysLabel;
@property (weak, nonatomic) IBOutlet UILabel *sysLabel;
@property (weak, nonatomic) IBOutlet UILabel *diaLabel;
@property (weak, nonatomic) IBOutlet UILabel *pulseLabel;
@property (weak, nonatomic) IBOutlet UITextView *logView;

@end

@implementation TestViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"GetHistory" style:UIBarButtonItemStylePlain target:self action:@selector(getHistory)];
}

- (void)getHistory
{
    // 请在测量结束后下发
    [self.bleManager sendToGetHistoryList];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    self.navigationItem.title = @"Disconnected";
    
    self.bleManager = [BTBloodPBLEManager shareBTBloodPBLEManager];
    self.bleManager.delegate = self;
    [self.bleManager setDeviceBleName:@"Biokit"];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    
    // 断开连接
    self.bleManager.selectDeviceIdt = nil;
    [self.bleManager disconnectDevice];
}
- (IBAction)getPowerClick:(id)sender {
    [self.bleManager sendToGetDevicePower];
}
- (IBAction)turnOffScreenClick:(id)sender {
    [self.bleManager sendToTurnOffScreen_13B4LT];
}
- (IBAction)turnOnScreenClick:(id)sender {
    [self.bleManager sendToTurnOnScreen_13B4LT];
}

- (IBAction)setUnitClick:(UIButton *)sender {
    
    if (sender.tag == 100) {
        [self.bleManager sendToSetUnit:BTBloodPressureUnitMmHg];
    }else if (sender.tag == 101){
        [self.bleManager sendToSetUnit:BTBloodPressureUnitKPa];
    }
}


#pragma mark - BTBloodPBLEManagerDelegate
- (void)BTBloodPBLEManagerDidUpdateState:(CBManagerState)state
{
    NSLog(@"[ScanViewController]BTBloodPBLEManagerDidUpdateState: %ld",state);
    if (state == CBManagerStatePoweredOn) {
        [self.bleManager startScan];
    }else{
        [SVProgressHUD showInfoWithStatus:@"Please turn on your iPhone's bluetooth"];
    }
}

- (void)BTBloodPBLEManagerDidConnectDevice:(BTBloodPBLEManager *)manager serialNumber:(NSString *)serialNumber
{
    self.navigationItem.title = [NSString stringWithFormat:@"Connected:%@",serialNumber];
    NSLog(@"serialNumber === %@",serialNumber);
    
}

- (void)BTBloodPBLEManagerDidFailToConnectDevice:(BTBloodPBLEManager *)manager
{
    self.navigationItem.title = @"Disconnected";
}

- (void)BTBloodPBLEManagerDidDisconnectDevice:(BTBloodPBLEManager *)manager
{
    self.navigationItem.title = @"Disconnected";
    
    // If the device is disconnected, you'd better restart scanning.
    [self.bleManager startScan];
}

/**
 收到当前测量中的动态收缩压
 
 @param systolicBP 收缩压
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedActiveSystolicBP:(NSInteger)systolicBP
{
    NSLog(@"%s:     sys=%ld",__func__,systolicBP);
    self.activeSysLabel.text = [NSString stringWithFormat:@"%ld",systolicBP];
}

/**
 收到血压测量结果
 
 @param systolicBP 收缩压
 @param diastolicBP 舒张压
 @param pulse 脉搏
 @param unit 血压单位
 @param isArrhythmia 是否心律不齐
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedMeasureResultSystolicBP:(NSInteger)systolicBP diastolicBP:(NSInteger)diastolicBP pulse:(NSInteger)pulse unit:(BTBloodPressureUnit)unit isArrhythmia:(BOOL)isArrhythmia
{
    NSLog(@"%s:     sys=%ld, dia=%ld, pul=%ld, isArrhythmia=%d",__func__,systolicBP,diastolicBP,pulse,isArrhythmia);
    
    // 1. SDK传输的数据均为mmHg，如果当前单位是 kPa，需要APP自行进行转换
    if (unit == BTBloodPressureUnitKPa) {
        // ...
    }
    
    self.sysLabel.text = [NSString stringWithFormat:@"%ld mmHg",systolicBP];
    self.diaLabel.text = [NSString stringWithFormat:@"%ld mmHg",diastolicBP];
    self.pulseLabel.text = [NSString stringWithFormat:@"%ld bpm",pulse];
    
    // 2. 如果需要切换单位，请在测量结束后下发
    [manager sendToSetUnit:BTBloodPressureUnitKPa];
}

/**
 收到测量出错信息
 
 @param error 错误码，见 BTBloodPressureError 声明
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedMeasureFailed:(BTBloodPressureError)error
{
    NSLog(@"%s:     err=%ld",__func__,error);
    [SVProgressHUD showErrorWithStatus:[NSString stringWithFormat:@"Error! code:%ld",error]];
    
    // 2. 如果需要切换单位，请在测量结束后下发
    [manager sendToSetUnit:BTBloodPressureUnitMmHg];
}

/**
 设备请求同步时间
 */
- (void)BTBloodPBLEManagerDidReceivedSyncTime:(BTBloodPBLEManager *)manager
{
    NSLog(@"%s ---",__func__);
    [manager sendToSyncTime:[NSDate date]];
}

/**
 收到历史记录
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedHistoryMeasureResultSystolicBP:(NSInteger)systolicBP diastolicBP:(NSInteger)diastolicBP pulse:(NSInteger)pulse isArrhythmia:(BOOL)isArrhythmia unit:(BTBloodPressureUnit)unit time:(NSString *)timeString index:(NSInteger)index totalCount:(NSInteger)totalCount
{
    NSLog(@"did received history: --- index=%ld, count=%ld, sys=%ld, dia=%ld, pul=%ld, isArrhythmia=%d, time=%@,",index, totalCount,systolicBP,diastolicBP,pulse,isArrhythmia,timeString);
    NSString *historyString = [NSString stringWithFormat:@"index=%ld, count=%ld, sys=%ld, dia=%ld, pul=%ld, isArrhythmia=%d, time=%@,",index, totalCount,systolicBP,diastolicBP,pulse,isArrhythmia,timeString];
    if (index == 1) {
        self.logView.text = @"";
    }
    self.logView.text = [NSString stringWithFormat:@"%@\n%@",self.logView.text,historyString];
}

/**
 无更多离线记录
 */
- (void)BTBloodPBLEManagerDidReceivedNoMoreHistory:(BTBloodPBLEManager *)manager
{
    NSLog(@"no more history");
}

/**
 收到设备电量
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedDevicePower:(int)power{
    NSLog(@"Did received Device Power:  %d%%",power);
}

/*
 收到下发设置单位ACK
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedSetUnitACK:(BTBloodPressureUnit)unit{
    NSLog(@"Did received Set Unit ACK:  %@",unit ? @"kpa":@"mmhg");
}

/**
 收到唤醒屏幕指令ACK（13B4-LT专用）
 */
- (void)BTBloodPBLEManagerDidReceivedTurnOnScreenACK_13B4LT:(BTBloodPBLEManager *)manager{
    
    NSLog(@"Did received Turn On Screen ACK（13B4-LT专用）");
}

/**
 收到熄灭屏幕指令ACK（13B4-LT专用）
 */
- (void)BTBloodPBLEManagerDidReceivedTurnOffScreenACK_13B4LT:(BTBloodPBLEManager *)manager{
    
    NSLog(@"Did received Turn Off Screen ACK（13B4-LT专用）");
}
@end
