//
//  BTBloodPBLEManager.h
//  BTBloodPBLEManager-Demo
//
//  Created by 倍泰 on 12/03/2019.
//  Copyright © 2019 ebelter. All rights reserved.
//

// 倍泰血压计

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CoreBluetooth.h>

@class BTBloodPBLEManager;

typedef enum : NSUInteger {
    BTBloodPBLEManagerStateDisconnected = 0,
    BTBloodPBLEManagerStateConnected,
} BTBloodPBLEManagerState;

typedef enum : NSUInteger {
    BTBloodPressureErrorDefault = 1,    //  测量结果异常
    BTBloodPressureError01,             //  检测不到结果
    BTBloodPressureError02,             //  干扰太大
    BTBloodPressureError03,             //  充气异常，打不上气或者压力超过上限
    BTBloodPressureErrorOther,          //  其他错误
    BTBloodPressureErrorLowPower,       //  电池电量过低，提示用户更换电池
} BTBloodPressureError;

typedef enum : NSUInteger {
    BTBloodPressureUnitMmHg,        //  mmHg
    BTBloodPressureUnitKPa,         //  kPa
} BTBloodPressureUnit;

@protocol BTBloodPBLEManagerDelegate <NSObject>

@optional


#pragma mark - BTBloodPBLEManagerDelegate(About Bluetooth Connection)

/**
 *  手机蓝牙状态改变
 */
- (void)BTBloodPBLEManagerDidUpdateState:(CBManagerState)state;

/**
 *  搜索到设备
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didDiscoverDeviceName:(NSString *)name macAddress:(NSData *)mac uuid:(NSUUID *)deviceUUID;

/**
 *  设备已连接
 */
- (void)BTBloodPBLEManagerDidConnectDevice:(BTBloodPBLEManager *)manager serialNumber:(NSString *)serialNumber;

/**
 *  设备连接失败
 */
- (void)BTBloodPBLEManagerDidFailToConnectDevice:(BTBloodPBLEManager *)manager ;

/**
 *  连接断开
 */
- (void)BTBloodPBLEManagerDidDisconnectDevice:(BTBloodPBLEManager *)manager;

#pragma mark - BTBloodPBLEManagerDelegate(Received and Parse Data)

/**
 收到当前测量中的动态收缩压

 @param systolicBP 收缩压
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedActiveSystolicBP:(NSInteger)systolicBP;

/**
 收到血压测量结果
 
 @param systolicBP 收缩压
 @param diastolicBP 舒张压
 @param pulse 脉搏
 @param unit 血压单位
 @param isArrhythmia 是否心律不齐
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedMeasureResultSystolicBP:(NSInteger)systolicBP diastolicBP:(NSInteger)diastolicBP pulse:(NSInteger)pulse unit:(BTBloodPressureUnit)unit isArrhythmia:(BOOL)isArrhythmia;

/**
 收到测量出错信息
 
 @param error 错误码，见 BTBloodPressureError 声明
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedMeasureFailed:(BTBloodPressureError)error;

/**
 收到设备请求同步时间
 */
- (void)BTBloodPBLEManagerDidReceivedSyncTime:(BTBloodPBLEManager *)manager;

/**
 收到血压测量历史记录
 
 @param systolicBP 收缩压
 @param diastolicBP 舒张压
 @param pulse 脉搏
 @param isArrhythmia 是否心律不齐
 @param unit 血压单位
 @param timeString 测量时间
 @param index 当前第几条历史记录  note:start from 1
 @param totalCount 历史记录总条数
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedHistoryMeasureResultSystolicBP:(NSInteger)systolicBP diastolicBP:(NSInteger)diastolicBP pulse:(NSInteger)pulse isArrhythmia:(BOOL)isArrhythmia unit:(BTBloodPressureUnit)unit time:(NSString *)timeString index:(NSInteger)index totalCount:(NSInteger)totalCount;

/**
 收到无历史记录
 */
- (void)BTBloodPBLEManagerDidReceivedNoMoreHistory:(BTBloodPBLEManager *)manager ;

/**
 收到设备电量
 @param power 电量
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedDevicePower:(int)power;

/**
 收到熄灭屏幕指令ACK（13B4-LT专用）
 */
- (void)BTBloodPBLEManagerDidReceivedTurnOffScreenACK_13B4LT:(BTBloodPBLEManager *)manager;

/**
 收到唤醒屏幕指令ACK（13B4-LT专用）
 */
- (void)BTBloodPBLEManagerDidReceivedTurnOnScreenACK_13B4LT:(BTBloodPBLEManager *)manager;

/**
 收到下发设置单位ACK
 @param unit 单位（mmHg/kPa）
 */
- (void)BTBloodPBLEManager:(BTBloodPBLEManager *)manager didReceivedSetUnitACK:(BTBloodPressureUnit)unit;
@end


@interface BTBloodPBLEManager : NSObject

@property (nonatomic,weak) id<BTBloodPBLEManagerDelegate> delegate;

/**
 手机系统蓝牙状态
 */
@property (nonatomic,assign) CBManagerState bleState;

/**
 设备连接状态
 */
@property (nonatomic,assign) BTBloodPBLEManagerState connectState;

/**
 要连接的设备的UUID
 */
@property (nonatomic,strong) NSUUID *selectDeviceIdt;

#pragma mark - Public method

/**
 实例化一个BTBloodPBLEManager
 */
+ (instancetype)shareBTBloodPBLEManager;

/**
 开始扫描周边设备
 */
- (void)startScan;

/**
 断开当前连接
 */
- (void)disconnectDevice;

/**
 停止扫描
 */
- (void)stopScan;

#pragma mark - send cmd
/**
 下发设置血压计单位
 @param unit 单位（mmHg/kPa）
 */
- (void)sendToSetUnit:(BTBloodPressureUnit)unit;
/**
 下发息灭屏幕
 */
- (void)sendToTurnOffScreen;
/*
 * 下发同步时间
 */
- (void)sendToSyncTime:(NSDate *)date;
/**
 下发获取历史数据
 */
- (void)sendToGetHistoryList;
/**
 下发清空历史数据
 */
- (void)sendToDeleteHistoryList;
/**
 下发获取设备电量
 */
- (void)sendToGetDevicePower;

/**
 指定设备蓝牙名
 @param bleNameKeyword 设备蓝牙名（只需要传入关键字）
 */
- (void)setDeviceBleName:(NSString *)bleNameKeyword;

/**
 下发熄灭屏幕（13B4-LT专用）
 在血压计测量过程中可执行
 */
- (void)sendToTurnOffScreen_13B4LT;

/**
 下发唤醒屏幕（13B4-LT专用）
 在血压计测量过程中可执行
 */
- (void)sendToTurnOnScreen_13B4LT;
@end
